@@ -10,6 +10,7 @@ use Config::General qw/ParseConfig/;
 use Encode;
 use English qw/-no_match_vars/;
 use File::HomeDir;
+use GnuPG::Options;
 use IPC::System::Simple qw/capturex/;
 use List::MoreUtils qw/uniq/;
 use List::Util qw/shuffle/;
@@ -33,6 +34,14 @@ See bin/parcimonie :)
 
 =head1 EXPORT
 
+=head1 COPYRIGHT
+
+Copyright (C) 2010-2018 intrigeri <intrigeri@boum.org>
+
+=head1 LICENSE
+
+Licensed under the same terms as Perl itself.
+
 =cut
 
 our @EXPORT = qw/pickRandomItems gpgPublicKeys gpgRecvKeys gpg_is_v21
@@ -77,7 +86,7 @@ Returns true iff. it is 2.1 or newer.
 
 =cut
 sub gpg_is_v21 {
-    version->parse(App::Parcimonie::GnuPG::Interface->new()->version())
+    version->parse(GnuPG::Interface->new()->version())
         >= version->parse('2.1.0');
 }
 
@@ -94,8 +103,10 @@ sub gpgPublicKeys {
     my $gnupg_options = shift;
     my %gi_args       = @_;
 
-    my $gnupg = App::Parcimonie::GnuPG::Interface->new(%gi_args);
-    $gnupg->options->hash_init(%{ clone($gnupg_options) });
+    my $gnupg = App::Parcimonie::GnuPG::Interface->new(
+        %gi_args,
+        options => GnuPG::Options->new(%{clone($gnupg_options)}),
+    );
     $gnupg->get_public_keys_hex();
 }
 
@@ -114,8 +125,10 @@ sub gpgRecvKeys {
     my $gnupg_options = shift;
     my %gi_args       = @_;
 
-    my $gnupg = App::Parcimonie::GnuPG::Interface->new(%gi_args);
-    $gnupg->options->hash_init(%{ clone($gnupg_options) });
+    my $gnupg = App::Parcimonie::GnuPG::Interface->new(
+        %gi_args,
+        options => GnuPG::Options->new(%{clone($gnupg_options)}),
+    );
     my $err_h = IO::Handle->new();
     my $handles = GnuPG::Handles->new(stderr => $err_h);
     my $pid = $gnupg->recv_keys( handles => $handles, command_args => $keyids );
@@ -171,23 +184,20 @@ sub checkGpgHasDefinedKeyserver {
     my $gnupg_options = shift;
     my $arg_ref       = shift;
     my $gnupg_homedir = $gnupg_options->{homedir};
-    my $gnupg2        = $arg_ref->{gnupg2};
 
-    if ($gnupg2) {
-        my @homedir_args = defined $gnupg_homedir
-            ? ('--homedir', $gnupg_homedir)
-            : ();
-        my @output = capturex(
-            'gpg-connect-agent', @homedir_args,
-            qw{--dirmngr keyserver /bye}
-        );
-        my $res = pop @output;
-        $res eq "OK\n" || croak "Agent replied: $res";
-        if (@output) {
-            my $last_keyserver = pop @output;
-            if ($last_keyserver =~ m{\A [S] \s+ KEYSERVER \s+}xms) {
-                return;
-            }
+    my @homedir_args = defined $gnupg_homedir
+        ? ('--homedir', $gnupg_homedir)
+        : ();
+    my @output = capturex(
+        'gpg-connect-agent', @homedir_args,
+        qw{--dirmngr keyserver /bye}
+    );
+    my $res = pop @output;
+    $res eq "OK\n" || croak "Agent replied: $res";
+    if (@output) {
+        my $last_keyserver = pop @output;
+        if ($last_keyserver =~ m{\A [S] \s+ KEYSERVER \s+}xms) {
+            return;
         }
     }
 
