@@ -25,11 +25,13 @@ use POSIX;
 setlocale(LC_MESSAGES, "");
 textdomain("parcimonie-applet");
 
+use Time::Duration;
 use Try::Tiny;
 
 use namespace::clean;
 
 with 'App::Parcimonie::Role::HasEncoding';
+use MooX::StrictConstructor;
 
 
 =head1 ATTRIBUTES
@@ -243,6 +245,9 @@ sub init_dbus_watcher {
     $self->dbus_object->connect_to_signal("FetchEnd", sub {
         $self->signal_fetch_end_cb(@_);
     });
+    $self->dbus_object->connect_to_signal("Sleeping", sub {
+        $self->signal_sleeping_cb(@_);
+    });
 }
 
 sub append_mesg {
@@ -298,19 +303,23 @@ sub signal_fetch_end_cb {
     $self->statusicon->set_visible(TRUE);
     Glib::Timeout->add(
         $self->icon_display_time * 1000,
-        sub { $self->now_resting; }
+        sub { 1 }
     );
 }
 
-sub now_resting {
-    my $self = shift;
+sub signal_sleeping_cb {
+    my $self     = shift;
+    my $duration = shift;
+
+    # TRANSLATORS: sleeping time
+    my $mesg = $self->encoding->decode(
+        sprintf(gettext('Sleeping for %s...'), duration($duration))
+    );
+    $self->debug($mesg);
     $self->statusicon->set_from_stock('gtk-media-pause');
-    $self->statusicon->set_tooltip_text($self->encoding->decode(
-        gettext('Having a rest.')
-    ));
+    $self->statusicon->set_tooltip_text($mesg);
+    $self->append_mesg($mesg);
     $self->statusicon->set_visible(TRUE);
-    # return false so that the Glib::Timeout stops looping
-    return;
 }
 
 no Moo;
