@@ -30,3 +30,6 @@ dbus_signal("FetchBegin", ["string"]);
 
 # args: keyid, success, error message
 dbus_signal("FetchEnd", ["string", "bool", "string"]);
+
+# args: duration
+dbus_signal("Sleeping", ["uint32"]);
