@@ -18,6 +18,9 @@ use IPC::System::Simple qw{system systemx};
 
 use namespace::clean;
 
+# This child class cannot use MooX::StrictConstructor:
+# see "Inheritance" section in its doc for details.
+
 extends 'GnuPG::Interface';
 
 has 'already_torified' => (
@@ -27,37 +30,20 @@ has 'already_torified' => (
     default  => sub { 0; },
 );
 
-has 'gnupg2' => (
-    isa      => 'Bool',
-    is       => 'rw',
-    required => 0,
-    default  => sub { 0; },
-);
-
 after 'BUILD' => sub {
     my $self = shift;
-    if ($self->gnupg2) {
-        unless ($self->already_torified) {
-            my $gnupg_homedir = defined $self->options->homedir()
-                ? $self->options->homedir()
-                : '';
-            system(
-                q{echo 'use-tor:0:1' | } .
-                "GNUPGHOME='$gnupg_homedir' gpgconf --change-options dirmngr"
-            );
-            # Passing --runtime to the previous command does not work,
-            # so we have to:
-            system("GNUPGHOME='$gnupg_homedir' gpgconf --reload dirmngr");
-        }
-        $self->call('gpg2');
-    }
-    else {
-        unless ($self->already_torified) {
-            foreach my $prog (qw{torsocks parcimonie-torified-gpg}) {
-                defined which($prog) or croak "$prog not found in \$PATH";
-            }
-            $self->call('parcimonie-torified-gpg');
-        }
+    unless ($self->already_torified) {
+        my $gnupg_homedir = defined $self->options->homedir()
+            ? $self->options->homedir()
+            : '';
+        system(
+            q{echo 'use-tor:0:1' | } .
+            "GNUPGHOME='$gnupg_homedir' gpgconf --change-options dirmngr " .
+            ">/dev/null"
+        );
+        # Passing --runtime to the previous command does not work,
+        # so we have to:
+        system("GNUPGHOME='$gnupg_homedir' gpgconf --reload dirmngr");
     }
 };
 
